@@ -8,7 +8,7 @@ rm -r test/
 rm -r pollination_sdk.egg-info/
 
 
-npx openapi-generator generate \
+npx @openapitools/openapi-generator-cli generate \
   -i https://api.pollination.cloud/sdk_openapi.json \
   -t .openapi-generator/templates/python \
   -g python \
